/****************************************************************************
** Meta object code from reading C++ file 'AudioConfigDialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../mumble-1.5.901/src/mumble/AudioConfigDialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AudioConfigDialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AudioInputDialog_t {
    QByteArrayData data[35];
    char stringdata0[800];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AudioInputDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AudioInputDialog_t qt_meta_stringdata_AudioInputDialog = {
    {
QT_MOC_LITERAL(0, 0, 16), // "AudioInputDialog"
QT_MOC_LITERAL(1, 17, 4), // "save"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 4), // "load"
QT_MOC_LITERAL(4, 28, 8), // "Settings"
QT_MOC_LITERAL(5, 37, 1), // "r"
QT_MOC_LITERAL(6, 39, 13), // "updateBitrate"
QT_MOC_LITERAL(7, 53, 16), // "continuePlayback"
QT_MOC_LITERAL(8, 70, 26), // "verifyMicrophonePermission"
QT_MOC_LITERAL(9, 97, 26), // "on_qcbEnableCuePTT_clicked"
QT_MOC_LITERAL(10, 124, 26), // "on_qcbEnableCueVAD_clicked"
QT_MOC_LITERAL(11, 151, 31), // "on_qpbPushClickBrowseOn_clicked"
QT_MOC_LITERAL(12, 183, 32), // "on_qpbPushClickBrowseOff_clicked"
QT_MOC_LITERAL(13, 216, 30), // "on_qpbPushClickPreview_clicked"
QT_MOC_LITERAL(14, 247, 28), // "on_qpbPushClickReset_clicked"
QT_MOC_LITERAL(15, 276, 21), // "on_qcbMuteCue_clicked"
QT_MOC_LITERAL(16, 298, 27), // "on_qpbMuteCueBrowse_clicked"
QT_MOC_LITERAL(17, 326, 28), // "on_qpbMuteCuePreview_clicked"
QT_MOC_LITERAL(18, 355, 30), // "on_qsTransmitHold_valueChanged"
QT_MOC_LITERAL(19, 386, 1), // "v"
QT_MOC_LITERAL(20, 388, 24), // "on_qsFrames_valueChanged"
QT_MOC_LITERAL(21, 413, 25), // "on_qsQuality_valueChanged"
QT_MOC_LITERAL(22, 439, 21), // "on_qsAmp_valueChanged"
QT_MOC_LITERAL(23, 461, 28), // "on_qsDoublePush_valueChanged"
QT_MOC_LITERAL(24, 490, 25), // "on_qsPTTHold_valueChanged"
QT_MOC_LITERAL(25, 516, 29), // "on_qsTransmitMin_valueChanged"
QT_MOC_LITERAL(26, 546, 29), // "on_qsTransmitMax_valueChanged"
QT_MOC_LITERAL(27, 576, 39), // "on_qsSpeexNoiseSupStrength_va..."
QT_MOC_LITERAL(28, 616, 34), // "on_qcbTransmit_currentIndexCh..."
QT_MOC_LITERAL(29, 651, 32), // "on_qcbSystem_currentIndexChanged"
QT_MOC_LITERAL(30, 684, 15), // "on_Tick_timeout"
QT_MOC_LITERAL(31, 700, 36), // "on_qcbIdleAction_currentIndex..."
QT_MOC_LITERAL(32, 737, 27), // "on_qrbNoiseSupSpeex_toggled"
QT_MOC_LITERAL(33, 765, 7), // "checked"
QT_MOC_LITERAL(34, 773, 26) // "on_qrbNoiseSupBoth_toggled"

    },
    "AudioInputDialog\0save\0\0load\0Settings\0"
    "r\0updateBitrate\0continuePlayback\0"
    "verifyMicrophonePermission\0"
    "on_qcbEnableCuePTT_clicked\0"
    "on_qcbEnableCueVAD_clicked\0"
    "on_qpbPushClickBrowseOn_clicked\0"
    "on_qpbPushClickBrowseOff_clicked\0"
    "on_qpbPushClickPreview_clicked\0"
    "on_qpbPushClickReset_clicked\0"
    "on_qcbMuteCue_clicked\0on_qpbMuteCueBrowse_clicked\0"
    "on_qpbMuteCuePreview_clicked\0"
    "on_qsTransmitHold_valueChanged\0v\0"
    "on_qsFrames_valueChanged\0"
    "on_qsQuality_valueChanged\0"
    "on_qsAmp_valueChanged\0"
    "on_qsDoublePush_valueChanged\0"
    "on_qsPTTHold_valueChanged\0"
    "on_qsTransmitMin_valueChanged\0"
    "on_qsTransmitMax_valueChanged\0"
    "on_qsSpeexNoiseSupStrength_valueChanged\0"
    "on_qcbTransmit_currentIndexChanged\0"
    "on_qcbSystem_currentIndexChanged\0"
    "on_Tick_timeout\0on_qcbIdleAction_currentIndexChanged\0"
    "on_qrbNoiseSupSpeex_toggled\0checked\0"
    "on_qrbNoiseSupBoth_toggled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AudioInputDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  159,    2, 0x0a /* Public */,
       3,    1,  160,    2, 0x0a /* Public */,
       6,    0,  163,    2, 0x0a /* Public */,
       7,    0,  164,    2, 0x0a /* Public */,
       8,    0,  165,    2, 0x0a /* Public */,
       9,    0,  166,    2, 0x0a /* Public */,
      10,    0,  167,    2, 0x0a /* Public */,
      11,    0,  168,    2, 0x0a /* Public */,
      12,    0,  169,    2, 0x0a /* Public */,
      13,    0,  170,    2, 0x0a /* Public */,
      14,    0,  171,    2, 0x0a /* Public */,
      15,    1,  172,    2, 0x0a /* Public */,
      16,    0,  175,    2, 0x0a /* Public */,
      17,    0,  176,    2, 0x0a /* Public */,
      18,    1,  177,    2, 0x0a /* Public */,
      20,    1,  180,    2, 0x0a /* Public */,
      21,    1,  183,    2, 0x0a /* Public */,
      22,    1,  186,    2, 0x0a /* Public */,
      23,    1,  189,    2, 0x0a /* Public */,
      24,    1,  192,    2, 0x0a /* Public */,
      25,    0,  195,    2, 0x0a /* Public */,
      26,    0,  196,    2, 0x0a /* Public */,
      27,    1,  197,    2, 0x0a /* Public */,
      28,    1,  200,    2, 0x0a /* Public */,
      29,    1,  203,    2, 0x0a /* Public */,
      30,    0,  206,    2, 0x0a /* Public */,
      31,    1,  207,    2, 0x0a /* Public */,
      32,    1,  210,    2, 0x0a /* Public */,
      34,    1,  213,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   19,
    QMetaType::Void, QMetaType::Bool,   33,
    QMetaType::Void, QMetaType::Bool,   33,

       0        // eod
};

void AudioInputDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AudioInputDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load((*reinterpret_cast< const Settings(*)>(_a[1]))); break;
        case 2: _t->updateBitrate(); break;
        case 3: _t->continuePlayback(); break;
        case 4: _t->verifyMicrophonePermission(); break;
        case 5: _t->on_qcbEnableCuePTT_clicked(); break;
        case 6: _t->on_qcbEnableCueVAD_clicked(); break;
        case 7: _t->on_qpbPushClickBrowseOn_clicked(); break;
        case 8: _t->on_qpbPushClickBrowseOff_clicked(); break;
        case 9: _t->on_qpbPushClickPreview_clicked(); break;
        case 10: _t->on_qpbPushClickReset_clicked(); break;
        case 11: _t->on_qcbMuteCue_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 12: _t->on_qpbMuteCueBrowse_clicked(); break;
        case 13: _t->on_qpbMuteCuePreview_clicked(); break;
        case 14: _t->on_qsTransmitHold_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->on_qsFrames_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->on_qsQuality_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->on_qsAmp_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->on_qsDoublePush_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->on_qsPTTHold_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->on_qsTransmitMin_valueChanged(); break;
        case 21: _t->on_qsTransmitMax_valueChanged(); break;
        case 22: _t->on_qsSpeexNoiseSupStrength_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->on_qcbTransmit_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->on_qcbSystem_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 25: _t->on_Tick_timeout(); break;
        case 26: _t->on_qcbIdleAction_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->on_qrbNoiseSupSpeex_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->on_qrbNoiseSupBoth_toggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AudioInputDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<ConfigWidget::staticMetaObject>(),
    qt_meta_stringdata_AudioInputDialog.data,
    qt_meta_data_AudioInputDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AudioInputDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioInputDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AudioInputDialog.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::AudioInput"))
        return static_cast< Ui::AudioInput*>(this);
    return ConfigWidget::qt_metacast(_clname);
}

int AudioInputDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ConfigWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 29;
    }
    return _id;
}
struct qt_meta_stringdata_AudioOutputDialog_t {
    QByteArrayData data[27];
    char stringdata0[629];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AudioOutputDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AudioOutputDialog_t qt_meta_stringdata_AudioOutputDialog = {
    {
QT_MOC_LITERAL(0, 0, 17), // "AudioOutputDialog"
QT_MOC_LITERAL(1, 18, 4), // "save"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 4), // "load"
QT_MOC_LITERAL(4, 29, 8), // "Settings"
QT_MOC_LITERAL(5, 38, 1), // "r"
QT_MOC_LITERAL(6, 40, 23), // "on_qsDelay_valueChanged"
QT_MOC_LITERAL(7, 64, 1), // "v"
QT_MOC_LITERAL(8, 66, 24), // "on_qsJitter_valueChanged"
QT_MOC_LITERAL(9, 91, 24), // "on_qsVolume_valueChanged"
QT_MOC_LITERAL(10, 116, 29), // "on_qsOtherVolume_valueChanged"
QT_MOC_LITERAL(11, 146, 29), // "on_qsPacketDelay_valueChanged"
QT_MOC_LITERAL(12, 176, 28), // "on_qsPacketLoss_valueChanged"
QT_MOC_LITERAL(13, 205, 34), // "on_qcbLoopback_currentIndexCh..."
QT_MOC_LITERAL(14, 240, 29), // "on_qsMinDistance_valueChanged"
QT_MOC_LITERAL(15, 270, 34), // "on_qsbMinimumDistance_valueCh..."
QT_MOC_LITERAL(16, 305, 29), // "on_qsMaxDistance_valueChanged"
QT_MOC_LITERAL(17, 335, 34), // "on_qsbMaximumDistance_valueCh..."
QT_MOC_LITERAL(18, 370, 23), // "on_qsBloom_valueChanged"
QT_MOC_LITERAL(19, 394, 24), // "on_qsbBloom_valueChanged"
QT_MOC_LITERAL(20, 419, 31), // "on_qsMinimumVolume_valueChanged"
QT_MOC_LITERAL(21, 451, 32), // "on_qsbMinimumVolume_valueChanged"
QT_MOC_LITERAL(22, 484, 32), // "on_qcbSystem_currentIndexChanged"
QT_MOC_LITERAL(23, 517, 35), // "on_qcbAttenuateOthersOnTalk_c..."
QT_MOC_LITERAL(24, 553, 7), // "checked"
QT_MOC_LITERAL(25, 561, 29), // "on_qcbAttenuateOthers_clicked"
QT_MOC_LITERAL(26, 591, 37) // "on_qcbOnlyAttenuateSameOutput..."

    },
    "AudioOutputDialog\0save\0\0load\0Settings\0"
    "r\0on_qsDelay_valueChanged\0v\0"
    "on_qsJitter_valueChanged\0"
    "on_qsVolume_valueChanged\0"
    "on_qsOtherVolume_valueChanged\0"
    "on_qsPacketDelay_valueChanged\0"
    "on_qsPacketLoss_valueChanged\0"
    "on_qcbLoopback_currentIndexChanged\0"
    "on_qsMinDistance_valueChanged\0"
    "on_qsbMinimumDistance_valueChanged\0"
    "on_qsMaxDistance_valueChanged\0"
    "on_qsbMaximumDistance_valueChanged\0"
    "on_qsBloom_valueChanged\0"
    "on_qsbBloom_valueChanged\0"
    "on_qsMinimumVolume_valueChanged\0"
    "on_qsbMinimumVolume_valueChanged\0"
    "on_qcbSystem_currentIndexChanged\0"
    "on_qcbAttenuateOthersOnTalk_clicked\0"
    "checked\0on_qcbAttenuateOthers_clicked\0"
    "on_qcbOnlyAttenuateSameOutput_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AudioOutputDialog[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x0a /* Public */,
       3,    1,  120,    2, 0x0a /* Public */,
       6,    1,  123,    2, 0x0a /* Public */,
       8,    1,  126,    2, 0x0a /* Public */,
       9,    1,  129,    2, 0x0a /* Public */,
      10,    1,  132,    2, 0x0a /* Public */,
      11,    1,  135,    2, 0x0a /* Public */,
      12,    1,  138,    2, 0x0a /* Public */,
      13,    1,  141,    2, 0x0a /* Public */,
      14,    1,  144,    2, 0x0a /* Public */,
      15,    1,  147,    2, 0x0a /* Public */,
      16,    1,  150,    2, 0x0a /* Public */,
      17,    1,  153,    2, 0x0a /* Public */,
      18,    1,  156,    2, 0x0a /* Public */,
      19,    1,  159,    2, 0x0a /* Public */,
      20,    1,  162,    2, 0x0a /* Public */,
      21,    1,  165,    2, 0x0a /* Public */,
      22,    1,  168,    2, 0x0a /* Public */,
      23,    1,  171,    2, 0x0a /* Public */,
      25,    1,  174,    2, 0x0a /* Public */,
      26,    1,  177,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Double,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Double,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    7,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Bool,   24,
    QMetaType::Void, QMetaType::Bool,   24,

       0        // eod
};

void AudioOutputDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AudioOutputDialog *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->save(); break;
        case 1: _t->load((*reinterpret_cast< const Settings(*)>(_a[1]))); break;
        case 2: _t->on_qsDelay_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_qsJitter_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_qsVolume_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->on_qsOtherVolume_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->on_qsPacketDelay_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_qsPacketLoss_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->on_qcbLoopback_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->on_qsMinDistance_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_qsbMinimumDistance_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 11: _t->on_qsMaxDistance_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->on_qsbMaximumDistance_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 13: _t->on_qsBloom_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->on_qsbBloom_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->on_qsMinimumVolume_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->on_qsbMinimumVolume_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->on_qcbSystem_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->on_qcbAttenuateOthersOnTalk_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: _t->on_qcbAttenuateOthers_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 20: _t->on_qcbOnlyAttenuateSameOutput_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AudioOutputDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<ConfigWidget::staticMetaObject>(),
    qt_meta_stringdata_AudioOutputDialog.data,
    qt_meta_data_AudioOutputDialog,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AudioOutputDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioOutputDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AudioOutputDialog.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::AudioOutput"))
        return static_cast< Ui::AudioOutput*>(this);
    return ConfigWidget::qt_metacast(_clname);
}

int AudioOutputDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ConfigWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
