/****************************************************************************
** Meta object code from reading C++ file 'ApplicationPalette.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../ApplicationPalette.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ApplicationPalette.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ApplicationPalette_t {
    QByteArrayData data[80];
    char stringdata0[1215];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ApplicationPalette_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ApplicationPalette_t qt_meta_stringdata_ApplicationPalette = {
    {
QT_MOC_LITERAL(0, 0, 18), // "ApplicationPalette"
QT_MOC_LITERAL(1, 19, 24), // "updateApplicationPalette"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 18), // "resetAllProperties"
QT_MOC_LITERAL(4, 64, 10), // "windowtext"
QT_MOC_LITERAL(5, 75, 17), // "windowtext_active"
QT_MOC_LITERAL(6, 93, 19), // "windowtext_disabled"
QT_MOC_LITERAL(7, 113, 19), // "windowtext_inactive"
QT_MOC_LITERAL(8, 133, 6), // "button"
QT_MOC_LITERAL(9, 140, 13), // "button_active"
QT_MOC_LITERAL(10, 154, 15), // "button_disabled"
QT_MOC_LITERAL(11, 170, 15), // "button_inactive"
QT_MOC_LITERAL(12, 186, 5), // "light"
QT_MOC_LITERAL(13, 192, 12), // "light_active"
QT_MOC_LITERAL(14, 205, 14), // "light_disabled"
QT_MOC_LITERAL(15, 220, 14), // "light_inactive"
QT_MOC_LITERAL(16, 235, 8), // "midlight"
QT_MOC_LITERAL(17, 244, 15), // "midlight_active"
QT_MOC_LITERAL(18, 260, 17), // "midlight_disabled"
QT_MOC_LITERAL(19, 278, 17), // "midlight_inactive"
QT_MOC_LITERAL(20, 296, 4), // "dark"
QT_MOC_LITERAL(21, 301, 11), // "dark_active"
QT_MOC_LITERAL(22, 313, 13), // "dark_disabled"
QT_MOC_LITERAL(23, 327, 13), // "dark_inactive"
QT_MOC_LITERAL(24, 341, 3), // "mid"
QT_MOC_LITERAL(25, 345, 10), // "mid_active"
QT_MOC_LITERAL(26, 356, 12), // "mid_disabled"
QT_MOC_LITERAL(27, 369, 12), // "mid_inactive"
QT_MOC_LITERAL(28, 382, 4), // "text"
QT_MOC_LITERAL(29, 387, 11), // "text_active"
QT_MOC_LITERAL(30, 399, 13), // "text_disabled"
QT_MOC_LITERAL(31, 413, 13), // "text_inactive"
QT_MOC_LITERAL(32, 427, 10), // "brighttext"
QT_MOC_LITERAL(33, 438, 17), // "brighttext_active"
QT_MOC_LITERAL(34, 456, 19), // "brighttext_disabled"
QT_MOC_LITERAL(35, 476, 19), // "brighttext_inactive"
QT_MOC_LITERAL(36, 496, 10), // "buttontext"
QT_MOC_LITERAL(37, 507, 17), // "buttontext_active"
QT_MOC_LITERAL(38, 525, 19), // "buttontext_disabled"
QT_MOC_LITERAL(39, 545, 19), // "buttontext_inactive"
QT_MOC_LITERAL(40, 565, 4), // "base"
QT_MOC_LITERAL(41, 570, 11), // "base_active"
QT_MOC_LITERAL(42, 582, 13), // "base_disabled"
QT_MOC_LITERAL(43, 596, 13), // "base_inactive"
QT_MOC_LITERAL(44, 610, 6), // "window"
QT_MOC_LITERAL(45, 617, 13), // "window_active"
QT_MOC_LITERAL(46, 631, 15), // "window_disabled"
QT_MOC_LITERAL(47, 647, 15), // "window_inactive"
QT_MOC_LITERAL(48, 663, 6), // "shadow"
QT_MOC_LITERAL(49, 670, 13), // "shadow_active"
QT_MOC_LITERAL(50, 684, 15), // "shadow_disabled"
QT_MOC_LITERAL(51, 700, 15), // "shadow_inactive"
QT_MOC_LITERAL(52, 716, 9), // "highlight"
QT_MOC_LITERAL(53, 726, 16), // "highlight_active"
QT_MOC_LITERAL(54, 743, 18), // "highlight_disabled"
QT_MOC_LITERAL(55, 762, 18), // "highlight_inactive"
QT_MOC_LITERAL(56, 781, 15), // "highlightedtext"
QT_MOC_LITERAL(57, 797, 22), // "highlightedtext_active"
QT_MOC_LITERAL(58, 820, 24), // "highlightedtext_disabled"
QT_MOC_LITERAL(59, 845, 24), // "highlightedtext_inactive"
QT_MOC_LITERAL(60, 870, 4), // "link"
QT_MOC_LITERAL(61, 875, 11), // "link_active"
QT_MOC_LITERAL(62, 887, 13), // "link_disabled"
QT_MOC_LITERAL(63, 901, 13), // "link_inactive"
QT_MOC_LITERAL(64, 915, 11), // "linkvisited"
QT_MOC_LITERAL(65, 927, 18), // "linkvisited_active"
QT_MOC_LITERAL(66, 946, 20), // "linkvisited_disabled"
QT_MOC_LITERAL(67, 967, 20), // "linkvisited_inactive"
QT_MOC_LITERAL(68, 988, 13), // "alternatebase"
QT_MOC_LITERAL(69, 1002, 20), // "alternatebase_active"
QT_MOC_LITERAL(70, 1023, 22), // "alternatebase_disabled"
QT_MOC_LITERAL(71, 1046, 22), // "alternatebase_inactive"
QT_MOC_LITERAL(72, 1069, 11), // "tooltipbase"
QT_MOC_LITERAL(73, 1081, 18), // "tooltipbase_active"
QT_MOC_LITERAL(74, 1100, 20), // "tooltipbase_disabled"
QT_MOC_LITERAL(75, 1121, 20), // "tooltipbase_inactive"
QT_MOC_LITERAL(76, 1142, 11), // "tooltiptext"
QT_MOC_LITERAL(77, 1154, 18), // "tooltiptext_active"
QT_MOC_LITERAL(78, 1173, 20), // "tooltiptext_disabled"
QT_MOC_LITERAL(79, 1194, 20) // "tooltiptext_inactive"

    },
    "ApplicationPalette\0updateApplicationPalette\0"
    "\0resetAllProperties\0windowtext\0"
    "windowtext_active\0windowtext_disabled\0"
    "windowtext_inactive\0button\0button_active\0"
    "button_disabled\0button_inactive\0light\0"
    "light_active\0light_disabled\0light_inactive\0"
    "midlight\0midlight_active\0midlight_disabled\0"
    "midlight_inactive\0dark\0dark_active\0"
    "dark_disabled\0dark_inactive\0mid\0"
    "mid_active\0mid_disabled\0mid_inactive\0"
    "text\0text_active\0text_disabled\0"
    "text_inactive\0brighttext\0brighttext_active\0"
    "brighttext_disabled\0brighttext_inactive\0"
    "buttontext\0buttontext_active\0"
    "buttontext_disabled\0buttontext_inactive\0"
    "base\0base_active\0base_disabled\0"
    "base_inactive\0window\0window_active\0"
    "window_disabled\0window_inactive\0shadow\0"
    "shadow_active\0shadow_disabled\0"
    "shadow_inactive\0highlight\0highlight_active\0"
    "highlight_disabled\0highlight_inactive\0"
    "highlightedtext\0highlightedtext_active\0"
    "highlightedtext_disabled\0"
    "highlightedtext_inactive\0link\0link_active\0"
    "link_disabled\0link_inactive\0linkvisited\0"
    "linkvisited_active\0linkvisited_disabled\0"
    "linkvisited_inactive\0alternatebase\0"
    "alternatebase_active\0alternatebase_disabled\0"
    "alternatebase_inactive\0tooltipbase\0"
    "tooltipbase_active\0tooltipbase_disabled\0"
    "tooltipbase_inactive\0tooltiptext\0"
    "tooltiptext_active\0tooltiptext_disabled\0"
    "tooltiptext_inactive"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ApplicationPalette[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
      76,   26, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    0,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       4, QMetaType::QBrush, 0x00095003,
       5, QMetaType::QBrush, 0x00095003,
       6, QMetaType::QBrush, 0x00095003,
       7, QMetaType::QBrush, 0x00095003,
       8, QMetaType::QBrush, 0x00095003,
       9, QMetaType::QBrush, 0x00095003,
      10, QMetaType::QBrush, 0x00095003,
      11, QMetaType::QBrush, 0x00095003,
      12, QMetaType::QBrush, 0x00095003,
      13, QMetaType::QBrush, 0x00095003,
      14, QMetaType::QBrush, 0x00095003,
      15, QMetaType::QBrush, 0x00095003,
      16, QMetaType::QBrush, 0x00095003,
      17, QMetaType::QBrush, 0x00095003,
      18, QMetaType::QBrush, 0x00095003,
      19, QMetaType::QBrush, 0x00095003,
      20, QMetaType::QBrush, 0x00095003,
      21, QMetaType::QBrush, 0x00095003,
      22, QMetaType::QBrush, 0x00095003,
      23, QMetaType::QBrush, 0x00095003,
      24, QMetaType::QBrush, 0x00095003,
      25, QMetaType::QBrush, 0x00095003,
      26, QMetaType::QBrush, 0x00095003,
      27, QMetaType::QBrush, 0x00095003,
      28, QMetaType::QBrush, 0x00095003,
      29, QMetaType::QBrush, 0x00095003,
      30, QMetaType::QBrush, 0x00095003,
      31, QMetaType::QBrush, 0x00095003,
      32, QMetaType::QBrush, 0x00095003,
      33, QMetaType::QBrush, 0x00095003,
      34, QMetaType::QBrush, 0x00095003,
      35, QMetaType::QBrush, 0x00095003,
      36, QMetaType::QBrush, 0x00095003,
      37, QMetaType::QBrush, 0x00095003,
      38, QMetaType::QBrush, 0x00095003,
      39, QMetaType::QBrush, 0x00095003,
      40, QMetaType::QBrush, 0x00095003,
      41, QMetaType::QBrush, 0x00095003,
      42, QMetaType::QBrush, 0x00095003,
      43, QMetaType::QBrush, 0x00095003,
      44, QMetaType::QBrush, 0x00095003,
      45, QMetaType::QBrush, 0x00095003,
      46, QMetaType::QBrush, 0x00095003,
      47, QMetaType::QBrush, 0x00095003,
      48, QMetaType::QBrush, 0x00095003,
      49, QMetaType::QBrush, 0x00095003,
      50, QMetaType::QBrush, 0x00095003,
      51, QMetaType::QBrush, 0x00095003,
      52, QMetaType::QBrush, 0x00095003,
      53, QMetaType::QBrush, 0x00095003,
      54, QMetaType::QBrush, 0x00095003,
      55, QMetaType::QBrush, 0x00095003,
      56, QMetaType::QBrush, 0x00095003,
      57, QMetaType::QBrush, 0x00095003,
      58, QMetaType::QBrush, 0x00095003,
      59, QMetaType::QBrush, 0x00095003,
      60, QMetaType::QBrush, 0x00095003,
      61, QMetaType::QBrush, 0x00095003,
      62, QMetaType::QBrush, 0x00095003,
      63, QMetaType::QBrush, 0x00095003,
      64, QMetaType::QBrush, 0x00095003,
      65, QMetaType::QBrush, 0x00095003,
      66, QMetaType::QBrush, 0x00095003,
      67, QMetaType::QBrush, 0x00095003,
      68, QMetaType::QBrush, 0x00095003,
      69, QMetaType::QBrush, 0x00095003,
      70, QMetaType::QBrush, 0x00095003,
      71, QMetaType::QBrush, 0x00095003,
      72, QMetaType::QBrush, 0x00095003,
      73, QMetaType::QBrush, 0x00095003,
      74, QMetaType::QBrush, 0x00095003,
      75, QMetaType::QBrush, 0x00095003,
      76, QMetaType::QBrush, 0x00095003,
      77, QMetaType::QBrush, 0x00095003,
      78, QMetaType::QBrush, 0x00095003,
      79, QMetaType::QBrush, 0x00095003,

       0        // eod
};

void ApplicationPalette::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ApplicationPalette *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateApplicationPalette(); break;
        case 1: _t->resetAllProperties(); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<ApplicationPalette *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QBrush*>(_v) = _t->get_windowtext(); break;
        case 1: *reinterpret_cast< QBrush*>(_v) = _t->get_windowtext_active(); break;
        case 2: *reinterpret_cast< QBrush*>(_v) = _t->get_windowtext_disabled(); break;
        case 3: *reinterpret_cast< QBrush*>(_v) = _t->get_windowtext_inactive(); break;
        case 4: *reinterpret_cast< QBrush*>(_v) = _t->get_button(); break;
        case 5: *reinterpret_cast< QBrush*>(_v) = _t->get_button_active(); break;
        case 6: *reinterpret_cast< QBrush*>(_v) = _t->get_button_disabled(); break;
        case 7: *reinterpret_cast< QBrush*>(_v) = _t->get_button_inactive(); break;
        case 8: *reinterpret_cast< QBrush*>(_v) = _t->get_light(); break;
        case 9: *reinterpret_cast< QBrush*>(_v) = _t->get_light_active(); break;
        case 10: *reinterpret_cast< QBrush*>(_v) = _t->get_light_disabled(); break;
        case 11: *reinterpret_cast< QBrush*>(_v) = _t->get_light_inactive(); break;
        case 12: *reinterpret_cast< QBrush*>(_v) = _t->get_midlight(); break;
        case 13: *reinterpret_cast< QBrush*>(_v) = _t->get_midlight_active(); break;
        case 14: *reinterpret_cast< QBrush*>(_v) = _t->get_midlight_disabled(); break;
        case 15: *reinterpret_cast< QBrush*>(_v) = _t->get_midlight_inactive(); break;
        case 16: *reinterpret_cast< QBrush*>(_v) = _t->get_dark(); break;
        case 17: *reinterpret_cast< QBrush*>(_v) = _t->get_dark_active(); break;
        case 18: *reinterpret_cast< QBrush*>(_v) = _t->get_dark_disabled(); break;
        case 19: *reinterpret_cast< QBrush*>(_v) = _t->get_dark_inactive(); break;
        case 20: *reinterpret_cast< QBrush*>(_v) = _t->get_mid(); break;
        case 21: *reinterpret_cast< QBrush*>(_v) = _t->get_mid_active(); break;
        case 22: *reinterpret_cast< QBrush*>(_v) = _t->get_mid_disabled(); break;
        case 23: *reinterpret_cast< QBrush*>(_v) = _t->get_mid_inactive(); break;
        case 24: *reinterpret_cast< QBrush*>(_v) = _t->get_text(); break;
        case 25: *reinterpret_cast< QBrush*>(_v) = _t->get_text_active(); break;
        case 26: *reinterpret_cast< QBrush*>(_v) = _t->get_text_disabled(); break;
        case 27: *reinterpret_cast< QBrush*>(_v) = _t->get_text_inactive(); break;
        case 28: *reinterpret_cast< QBrush*>(_v) = _t->get_brighttext(); break;
        case 29: *reinterpret_cast< QBrush*>(_v) = _t->get_brighttext_active(); break;
        case 30: *reinterpret_cast< QBrush*>(_v) = _t->get_brighttext_disabled(); break;
        case 31: *reinterpret_cast< QBrush*>(_v) = _t->get_brighttext_inactive(); break;
        case 32: *reinterpret_cast< QBrush*>(_v) = _t->get_buttontext(); break;
        case 33: *reinterpret_cast< QBrush*>(_v) = _t->get_buttontext_active(); break;
        case 34: *reinterpret_cast< QBrush*>(_v) = _t->get_buttontext_disabled(); break;
        case 35: *reinterpret_cast< QBrush*>(_v) = _t->get_buttontext_inactive(); break;
        case 36: *reinterpret_cast< QBrush*>(_v) = _t->get_base(); break;
        case 37: *reinterpret_cast< QBrush*>(_v) = _t->get_base_active(); break;
        case 38: *reinterpret_cast< QBrush*>(_v) = _t->get_base_disabled(); break;
        case 39: *reinterpret_cast< QBrush*>(_v) = _t->get_base_inactive(); break;
        case 40: *reinterpret_cast< QBrush*>(_v) = _t->get_window(); break;
        case 41: *reinterpret_cast< QBrush*>(_v) = _t->get_window_active(); break;
        case 42: *reinterpret_cast< QBrush*>(_v) = _t->get_window_disabled(); break;
        case 43: *reinterpret_cast< QBrush*>(_v) = _t->get_window_inactive(); break;
        case 44: *reinterpret_cast< QBrush*>(_v) = _t->get_shadow(); break;
        case 45: *reinterpret_cast< QBrush*>(_v) = _t->get_shadow_active(); break;
        case 46: *reinterpret_cast< QBrush*>(_v) = _t->get_shadow_disabled(); break;
        case 47: *reinterpret_cast< QBrush*>(_v) = _t->get_shadow_inactive(); break;
        case 48: *reinterpret_cast< QBrush*>(_v) = _t->get_highlight(); break;
        case 49: *reinterpret_cast< QBrush*>(_v) = _t->get_highlight_active(); break;
        case 50: *reinterpret_cast< QBrush*>(_v) = _t->get_highlight_disabled(); break;
        case 51: *reinterpret_cast< QBrush*>(_v) = _t->get_highlight_inactive(); break;
        case 52: *reinterpret_cast< QBrush*>(_v) = _t->get_highlightedtext(); break;
        case 53: *reinterpret_cast< QBrush*>(_v) = _t->get_highlightedtext_active(); break;
        case 54: *reinterpret_cast< QBrush*>(_v) = _t->get_highlightedtext_disabled(); break;
        case 55: *reinterpret_cast< QBrush*>(_v) = _t->get_highlightedtext_inactive(); break;
        case 56: *reinterpret_cast< QBrush*>(_v) = _t->get_link(); break;
        case 57: *reinterpret_cast< QBrush*>(_v) = _t->get_link_active(); break;
        case 58: *reinterpret_cast< QBrush*>(_v) = _t->get_link_disabled(); break;
        case 59: *reinterpret_cast< QBrush*>(_v) = _t->get_link_inactive(); break;
        case 60: *reinterpret_cast< QBrush*>(_v) = _t->get_linkvisited(); break;
        case 61: *reinterpret_cast< QBrush*>(_v) = _t->get_linkvisited_active(); break;
        case 62: *reinterpret_cast< QBrush*>(_v) = _t->get_linkvisited_disabled(); break;
        case 63: *reinterpret_cast< QBrush*>(_v) = _t->get_linkvisited_inactive(); break;
        case 64: *reinterpret_cast< QBrush*>(_v) = _t->get_alternatebase(); break;
        case 65: *reinterpret_cast< QBrush*>(_v) = _t->get_alternatebase_active(); break;
        case 66: *reinterpret_cast< QBrush*>(_v) = _t->get_alternatebase_disabled(); break;
        case 67: *reinterpret_cast< QBrush*>(_v) = _t->get_alternatebase_inactive(); break;
        case 68: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltipbase(); break;
        case 69: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltipbase_active(); break;
        case 70: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltipbase_disabled(); break;
        case 71: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltipbase_inactive(); break;
        case 72: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltiptext(); break;
        case 73: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltiptext_active(); break;
        case 74: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltiptext_disabled(); break;
        case 75: *reinterpret_cast< QBrush*>(_v) = _t->get_tooltiptext_inactive(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<ApplicationPalette *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->set_windowtext(*reinterpret_cast< QBrush*>(_v)); break;
        case 1: _t->set_windowtext_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 2: _t->set_windowtext_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 3: _t->set_windowtext_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 4: _t->set_button(*reinterpret_cast< QBrush*>(_v)); break;
        case 5: _t->set_button_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 6: _t->set_button_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 7: _t->set_button_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 8: _t->set_light(*reinterpret_cast< QBrush*>(_v)); break;
        case 9: _t->set_light_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 10: _t->set_light_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 11: _t->set_light_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 12: _t->set_midlight(*reinterpret_cast< QBrush*>(_v)); break;
        case 13: _t->set_midlight_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 14: _t->set_midlight_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 15: _t->set_midlight_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 16: _t->set_dark(*reinterpret_cast< QBrush*>(_v)); break;
        case 17: _t->set_dark_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 18: _t->set_dark_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 19: _t->set_dark_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 20: _t->set_mid(*reinterpret_cast< QBrush*>(_v)); break;
        case 21: _t->set_mid_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 22: _t->set_mid_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 23: _t->set_mid_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 24: _t->set_text(*reinterpret_cast< QBrush*>(_v)); break;
        case 25: _t->set_text_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 26: _t->set_text_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 27: _t->set_text_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 28: _t->set_brighttext(*reinterpret_cast< QBrush*>(_v)); break;
        case 29: _t->set_brighttext_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 30: _t->set_brighttext_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 31: _t->set_brighttext_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 32: _t->set_buttontext(*reinterpret_cast< QBrush*>(_v)); break;
        case 33: _t->set_buttontext_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 34: _t->set_buttontext_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 35: _t->set_buttontext_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 36: _t->set_base(*reinterpret_cast< QBrush*>(_v)); break;
        case 37: _t->set_base_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 38: _t->set_base_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 39: _t->set_base_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 40: _t->set_window(*reinterpret_cast< QBrush*>(_v)); break;
        case 41: _t->set_window_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 42: _t->set_window_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 43: _t->set_window_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 44: _t->set_shadow(*reinterpret_cast< QBrush*>(_v)); break;
        case 45: _t->set_shadow_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 46: _t->set_shadow_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 47: _t->set_shadow_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 48: _t->set_highlight(*reinterpret_cast< QBrush*>(_v)); break;
        case 49: _t->set_highlight_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 50: _t->set_highlight_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 51: _t->set_highlight_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 52: _t->set_highlightedtext(*reinterpret_cast< QBrush*>(_v)); break;
        case 53: _t->set_highlightedtext_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 54: _t->set_highlightedtext_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 55: _t->set_highlightedtext_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 56: _t->set_link(*reinterpret_cast< QBrush*>(_v)); break;
        case 57: _t->set_link_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 58: _t->set_link_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 59: _t->set_link_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 60: _t->set_linkvisited(*reinterpret_cast< QBrush*>(_v)); break;
        case 61: _t->set_linkvisited_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 62: _t->set_linkvisited_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 63: _t->set_linkvisited_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 64: _t->set_alternatebase(*reinterpret_cast< QBrush*>(_v)); break;
        case 65: _t->set_alternatebase_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 66: _t->set_alternatebase_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 67: _t->set_alternatebase_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 68: _t->set_tooltipbase(*reinterpret_cast< QBrush*>(_v)); break;
        case 69: _t->set_tooltipbase_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 70: _t->set_tooltipbase_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 71: _t->set_tooltipbase_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        case 72: _t->set_tooltiptext(*reinterpret_cast< QBrush*>(_v)); break;
        case 73: _t->set_tooltiptext_active(*reinterpret_cast< QBrush*>(_v)); break;
        case 74: _t->set_tooltiptext_disabled(*reinterpret_cast< QBrush*>(_v)); break;
        case 75: _t->set_tooltiptext_inactive(*reinterpret_cast< QBrush*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ApplicationPalette::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_ApplicationPalette.data,
    qt_meta_data_ApplicationPalette,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ApplicationPalette::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ApplicationPalette::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ApplicationPalette.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ApplicationPalette::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 76;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 76;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 76;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 76;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 76;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 76;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
