/****************************************************************************
** Meta object code from reading C++ file 'AudioWizard.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../mumble-1.5.901/src/mumble/AudioWizard.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'AudioWizard.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AudioWizard_t {
    QByteArrayData data[25];
    char stringdata0[550];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AudioWizard_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AudioWizard_t qt_meta_stringdata_AudioWizard = {
    {
QT_MOC_LITERAL(0, 0, 11), // "AudioWizard"
QT_MOC_LITERAL(1, 12, 21), // "on_qcbInput_activated"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 27), // "on_qcbInputDevice_activated"
QT_MOC_LITERAL(4, 63, 22), // "on_qcbOutput_activated"
QT_MOC_LITERAL(5, 86, 28), // "on_qcbOutputDevice_activated"
QT_MOC_LITERAL(6, 115, 29), // "on_qsOutputDelay_valueChanged"
QT_MOC_LITERAL(7, 145, 24), // "on_qsMaxAmp_valueChanged"
QT_MOC_LITERAL(8, 170, 17), // "on_Ticker_timeout"
QT_MOC_LITERAL(9, 188, 21), // "on_qsVAD_valueChanged"
QT_MOC_LITERAL(10, 210, 22), // "on_qrAmplitude_clicked"
QT_MOC_LITERAL(11, 233, 16), // "on_qrSNR_clicked"
QT_MOC_LITERAL(12, 250, 16), // "on_qrPTT_clicked"
QT_MOC_LITERAL(13, 267, 17), // "on_qpbPTT_clicked"
QT_MOC_LITERAL(14, 285, 18), // "on_qcbEcho_clicked"
QT_MOC_LITERAL(15, 304, 23), // "on_qcbHeadphone_clicked"
QT_MOC_LITERAL(16, 328, 24), // "on_qcbPositional_clicked"
QT_MOC_LITERAL(17, 353, 29), // "on_qcbAttenuateOthers_clicked"
QT_MOC_LITERAL(18, 383, 26), // "on_qcbHighContrast_clicked"
QT_MOC_LITERAL(19, 410, 26), // "on_qrbQualityUltra_clicked"
QT_MOC_LITERAL(20, 437, 29), // "on_qrbQualityBalanced_clicked"
QT_MOC_LITERAL(21, 467, 24), // "on_qrbQualityLow_clicked"
QT_MOC_LITERAL(22, 492, 27), // "on_qrbQualityCustom_clicked"
QT_MOC_LITERAL(23, 520, 8), // "showPage"
QT_MOC_LITERAL(24, 529, 20) // "updateTriggerWidgets"

    },
    "AudioWizard\0on_qcbInput_activated\0\0"
    "on_qcbInputDevice_activated\0"
    "on_qcbOutput_activated\0"
    "on_qcbOutputDevice_activated\0"
    "on_qsOutputDelay_valueChanged\0"
    "on_qsMaxAmp_valueChanged\0on_Ticker_timeout\0"
    "on_qsVAD_valueChanged\0on_qrAmplitude_clicked\0"
    "on_qrSNR_clicked\0on_qrPTT_clicked\0"
    "on_qpbPTT_clicked\0on_qcbEcho_clicked\0"
    "on_qcbHeadphone_clicked\0"
    "on_qcbPositional_clicked\0"
    "on_qcbAttenuateOthers_clicked\0"
    "on_qcbHighContrast_clicked\0"
    "on_qrbQualityUltra_clicked\0"
    "on_qrbQualityBalanced_clicked\0"
    "on_qrbQualityLow_clicked\0"
    "on_qrbQualityCustom_clicked\0showPage\0"
    "updateTriggerWidgets"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AudioWizard[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,  129,    2, 0x0a /* Public */,
       3,    1,  132,    2, 0x0a /* Public */,
       4,    1,  135,    2, 0x0a /* Public */,
       5,    1,  138,    2, 0x0a /* Public */,
       6,    1,  141,    2, 0x0a /* Public */,
       7,    1,  144,    2, 0x0a /* Public */,
       8,    0,  147,    2, 0x0a /* Public */,
       9,    1,  148,    2, 0x0a /* Public */,
      10,    1,  151,    2, 0x0a /* Public */,
      11,    1,  154,    2, 0x0a /* Public */,
      12,    1,  157,    2, 0x0a /* Public */,
      13,    0,  160,    2, 0x0a /* Public */,
      14,    1,  161,    2, 0x0a /* Public */,
      15,    1,  164,    2, 0x0a /* Public */,
      16,    1,  167,    2, 0x0a /* Public */,
      17,    1,  170,    2, 0x0a /* Public */,
      18,    1,  173,    2, 0x0a /* Public */,
      19,    0,  176,    2, 0x0a /* Public */,
      20,    0,  177,    2, 0x0a /* Public */,
      21,    0,  178,    2, 0x0a /* Public */,
      22,    0,  179,    2, 0x0a /* Public */,
      23,    1,  180,    2, 0x0a /* Public */,
      24,    1,  183,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void AudioWizard::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AudioWizard *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_qcbInput_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->on_qcbInputDevice_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->on_qcbOutput_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_qcbOutputDevice_activated((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->on_qsOutputDelay_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->on_qsMaxAmp_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->on_Ticker_timeout(); break;
        case 7: _t->on_qsVAD_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->on_qrAmplitude_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 9: _t->on_qrSNR_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->on_qrPTT_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->on_qpbPTT_clicked(); break;
        case 12: _t->on_qcbEcho_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 13: _t->on_qcbHeadphone_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->on_qcbPositional_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->on_qcbAttenuateOthers_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->on_qcbHighContrast_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->on_qrbQualityUltra_clicked(); break;
        case 18: _t->on_qrbQualityBalanced_clicked(); break;
        case 19: _t->on_qrbQualityLow_clicked(); break;
        case 20: _t->on_qrbQualityCustom_clicked(); break;
        case 21: _t->showPage((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->updateTriggerWidgets((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AudioWizard::staticMetaObject = { {
    QMetaObject::SuperData::link<QWizard::staticMetaObject>(),
    qt_meta_stringdata_AudioWizard.data,
    qt_meta_data_AudioWizard,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AudioWizard::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AudioWizard::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AudioWizard.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::AudioWizard"))
        return static_cast< Ui::AudioWizard*>(this);
    return QWizard::qt_metacast(_clname);
}

int AudioWizard::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWizard::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 23;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
