/****************************************************************************
** Meta object code from reading C++ file 'ManualPlugin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../mumble-1.5.901/src/mumble/ManualPlugin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ManualPlugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Manual_t {
    QByteArrayData data[21];
    char stringdata0[461];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Manual_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Manual_t qt_meta_stringdata_Manual = {
    {
QT_MOC_LITERAL(0, 0, 6), // "Manual"
QT_MOC_LITERAL(1, 7, 21), // "on_qpbUnhinge_pressed"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 20), // "on_qpbLinked_clicked"
QT_MOC_LITERAL(4, 51, 23), // "on_qpbActivated_clicked"
QT_MOC_LITERAL(5, 75, 21), // "on_qdsbX_valueChanged"
QT_MOC_LITERAL(6, 97, 21), // "on_qdsbY_valueChanged"
QT_MOC_LITERAL(7, 119, 21), // "on_qdsbZ_valueChanged"
QT_MOC_LITERAL(8, 141, 26), // "on_qsbAzimuth_valueChanged"
QT_MOC_LITERAL(9, 168, 28), // "on_qsbElevation_valueChanged"
QT_MOC_LITERAL(10, 197, 25), // "on_qdAzimuth_valueChanged"
QT_MOC_LITERAL(11, 223, 27), // "on_qdElevation_valueChanged"
QT_MOC_LITERAL(12, 251, 29), // "on_qleContext_editingFinished"
QT_MOC_LITERAL(13, 281, 30), // "on_qleIdentity_editingFinished"
QT_MOC_LITERAL(14, 312, 20), // "on_buttonBox_clicked"
QT_MOC_LITERAL(15, 333, 16), // "QAbstractButton*"
QT_MOC_LITERAL(16, 350, 40), // "on_qsbSilentUserDisplaytime_v..."
QT_MOC_LITERAL(17, 391, 24), // "on_speakerPositionUpdate"
QT_MOC_LITERAL(18, 416, 11), // "PositionMap"
QT_MOC_LITERAL(19, 428, 9), // "positions"
QT_MOC_LITERAL(20, 438, 22) // "on_updateStaleSpeakers"

    },
    "Manual\0on_qpbUnhinge_pressed\0\0"
    "on_qpbLinked_clicked\0on_qpbActivated_clicked\0"
    "on_qdsbX_valueChanged\0on_qdsbY_valueChanged\0"
    "on_qdsbZ_valueChanged\0on_qsbAzimuth_valueChanged\0"
    "on_qsbElevation_valueChanged\0"
    "on_qdAzimuth_valueChanged\0"
    "on_qdElevation_valueChanged\0"
    "on_qleContext_editingFinished\0"
    "on_qleIdentity_editingFinished\0"
    "on_buttonBox_clicked\0QAbstractButton*\0"
    "on_qsbSilentUserDisplaytime_valueChanged\0"
    "on_speakerPositionUpdate\0PositionMap\0"
    "positions\0on_updateStaleSpeakers"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Manual[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      16,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   94,    2, 0x0a /* Public */,
       3,    1,   95,    2, 0x0a /* Public */,
       4,    1,   98,    2, 0x0a /* Public */,
       5,    1,  101,    2, 0x0a /* Public */,
       6,    1,  104,    2, 0x0a /* Public */,
       7,    1,  107,    2, 0x0a /* Public */,
       8,    1,  110,    2, 0x0a /* Public */,
       9,    1,  113,    2, 0x0a /* Public */,
      10,    1,  116,    2, 0x0a /* Public */,
      11,    1,  119,    2, 0x0a /* Public */,
      12,    0,  122,    2, 0x0a /* Public */,
      13,    0,  123,    2, 0x0a /* Public */,
      14,    1,  124,    2, 0x0a /* Public */,
      16,    1,  127,    2, 0x0a /* Public */,
      17,    1,  130,    2, 0x0a /* Public */,
      20,    0,  133,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 18,   19,
    QMetaType::Void,

       0        // eod
};

void Manual::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Manual *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_qpbUnhinge_pressed(); break;
        case 1: _t->on_qpbLinked_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->on_qpbActivated_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->on_qdsbX_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 4: _t->on_qdsbY_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 5: _t->on_qdsbZ_valueChanged((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 6: _t->on_qsbAzimuth_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->on_qsbElevation_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->on_qdAzimuth_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->on_qdElevation_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_qleContext_editingFinished(); break;
        case 11: _t->on_qleIdentity_editingFinished(); break;
        case 12: _t->on_buttonBox_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 13: _t->on_qsbSilentUserDisplaytime_valueChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->on_speakerPositionUpdate((*reinterpret_cast< PositionMap(*)>(_a[1]))); break;
        case 15: _t->on_updateStaleSpeakers(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< PositionMap >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Manual::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_Manual.data,
    qt_meta_data_Manual,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Manual::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Manual::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Manual.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::Manual"))
        return static_cast< Ui::Manual*>(this);
    return QDialog::qt_metacast(_clname);
}

int Manual::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}
struct qt_meta_stringdata_ManualPlugin_t {
    QByteArrayData data[1];
    char stringdata0[13];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ManualPlugin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ManualPlugin_t qt_meta_stringdata_ManualPlugin = {
    {
QT_MOC_LITERAL(0, 0, 12) // "ManualPlugin"

    },
    "ManualPlugin"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ManualPlugin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void ManualPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject ManualPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<LegacyPlugin::staticMetaObject>(),
    qt_meta_stringdata_ManualPlugin.data,
    qt_meta_data_ManualPlugin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ManualPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ManualPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ManualPlugin.stringdata0))
        return static_cast<void*>(this);
    return LegacyPlugin::qt_metacast(_clname);
}

int ManualPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = LegacyPlugin::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
