/****************************************************************************
** Meta object code from reading C++ file 'OverlayConfig.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../mumble-1.5.901/src/mumble/OverlayConfig.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'OverlayConfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_OverlayConfig_t {
    QByteArrayData data[31];
    char stringdata0[694];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_OverlayConfig_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_OverlayConfig_t qt_meta_stringdata_OverlayConfig = {
    {
QT_MOC_LITERAL(0, 0, 13), // "OverlayConfig"
QT_MOC_LITERAL(1, 14, 21), // "on_qpbInstall_clicked"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 23), // "on_qpbUninstall_clicked"
QT_MOC_LITERAL(4, 61, 46), // "on_qcbOverlayExclusionMode_cu..."
QT_MOC_LITERAL(5, 108, 36), // "on_qlwLaunchers_itemSelection..."
QT_MOC_LITERAL(6, 145, 26), // "on_qpbLaunchersAdd_clicked"
QT_MOC_LITERAL(7, 172, 29), // "on_qpbLaunchersRemove_clicked"
QT_MOC_LITERAL(8, 202, 36), // "on_qlwWhitelist_itemSelection..."
QT_MOC_LITERAL(9, 239, 26), // "on_qpbWhitelistAdd_clicked"
QT_MOC_LITERAL(10, 266, 29), // "on_qpbWhitelistRemove_clicked"
QT_MOC_LITERAL(11, 296, 32), // "on_qlwPaths_itemSelectionChanged"
QT_MOC_LITERAL(12, 329, 22), // "on_qpbPathsAdd_clicked"
QT_MOC_LITERAL(13, 352, 25), // "on_qpbPathsRemove_clicked"
QT_MOC_LITERAL(14, 378, 36), // "on_qlwBlacklist_itemSelection..."
QT_MOC_LITERAL(15, 415, 26), // "on_qpbBlacklistAdd_clicked"
QT_MOC_LITERAL(16, 442, 29), // "on_qpbBlacklistRemove_clicked"
QT_MOC_LITERAL(17, 472, 25), // "on_qcbEnable_stateChanged"
QT_MOC_LITERAL(18, 498, 26), // "on_qcbShowFps_stateChanged"
QT_MOC_LITERAL(19, 525, 27), // "on_qcbShowTime_stateChanged"
QT_MOC_LITERAL(20, 553, 21), // "on_qpbFpsFont_clicked"
QT_MOC_LITERAL(21, 575, 22), // "on_qpbFpsColor_clicked"
QT_MOC_LITERAL(22, 598, 24), // "on_qpbLoadPreset_clicked"
QT_MOC_LITERAL(23, 623, 24), // "on_qpbSavePreset_clicked"
QT_MOC_LITERAL(24, 648, 11), // "resizeScene"
QT_MOC_LITERAL(25, 660, 5), // "force"
QT_MOC_LITERAL(26, 666, 6), // "accept"
QT_MOC_LITERAL(27, 673, 4), // "save"
QT_MOC_LITERAL(28, 678, 4), // "load"
QT_MOC_LITERAL(29, 683, 8), // "Settings"
QT_MOC_LITERAL(30, 692, 1) // "r"

    },
    "OverlayConfig\0on_qpbInstall_clicked\0"
    "\0on_qpbUninstall_clicked\0"
    "on_qcbOverlayExclusionMode_currentIndexChanged\0"
    "on_qlwLaunchers_itemSelectionChanged\0"
    "on_qpbLaunchersAdd_clicked\0"
    "on_qpbLaunchersRemove_clicked\0"
    "on_qlwWhitelist_itemSelectionChanged\0"
    "on_qpbWhitelistAdd_clicked\0"
    "on_qpbWhitelistRemove_clicked\0"
    "on_qlwPaths_itemSelectionChanged\0"
    "on_qpbPathsAdd_clicked\0on_qpbPathsRemove_clicked\0"
    "on_qlwBlacklist_itemSelectionChanged\0"
    "on_qpbBlacklistAdd_clicked\0"
    "on_qpbBlacklistRemove_clicked\0"
    "on_qcbEnable_stateChanged\0"
    "on_qcbShowFps_stateChanged\0"
    "on_qcbShowTime_stateChanged\0"
    "on_qpbFpsFont_clicked\0on_qpbFpsColor_clicked\0"
    "on_qpbLoadPreset_clicked\0"
    "on_qpbSavePreset_clicked\0resizeScene\0"
    "force\0accept\0save\0load\0Settings\0r"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_OverlayConfig[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      27,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  149,    2, 0x09 /* Protected */,
       3,    0,  150,    2, 0x09 /* Protected */,
       4,    1,  151,    2, 0x09 /* Protected */,
       5,    0,  154,    2, 0x09 /* Protected */,
       6,    0,  155,    2, 0x09 /* Protected */,
       7,    0,  156,    2, 0x09 /* Protected */,
       8,    0,  157,    2, 0x09 /* Protected */,
       9,    0,  158,    2, 0x09 /* Protected */,
      10,    0,  159,    2, 0x09 /* Protected */,
      11,    0,  160,    2, 0x09 /* Protected */,
      12,    0,  161,    2, 0x09 /* Protected */,
      13,    0,  162,    2, 0x09 /* Protected */,
      14,    0,  163,    2, 0x09 /* Protected */,
      15,    0,  164,    2, 0x09 /* Protected */,
      16,    0,  165,    2, 0x09 /* Protected */,
      17,    1,  166,    2, 0x09 /* Protected */,
      18,    1,  169,    2, 0x09 /* Protected */,
      19,    1,  172,    2, 0x09 /* Protected */,
      20,    0,  175,    2, 0x09 /* Protected */,
      21,    0,  176,    2, 0x09 /* Protected */,
      22,    0,  177,    2, 0x09 /* Protected */,
      23,    0,  178,    2, 0x09 /* Protected */,
      24,    1,  179,    2, 0x09 /* Protected */,
      24,    0,  182,    2, 0x29 /* Protected | MethodCloned */,
      26,    0,  183,    2, 0x0a /* Public */,
      27,    0,  184,    2, 0x0a /* Public */,
      28,    1,  185,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   25,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 29,   30,

       0        // eod
};

void OverlayConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<OverlayConfig *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->on_qpbInstall_clicked(); break;
        case 1: _t->on_qpbUninstall_clicked(); break;
        case 2: _t->on_qcbOverlayExclusionMode_currentIndexChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->on_qlwLaunchers_itemSelectionChanged(); break;
        case 4: _t->on_qpbLaunchersAdd_clicked(); break;
        case 5: _t->on_qpbLaunchersRemove_clicked(); break;
        case 6: _t->on_qlwWhitelist_itemSelectionChanged(); break;
        case 7: _t->on_qpbWhitelistAdd_clicked(); break;
        case 8: _t->on_qpbWhitelistRemove_clicked(); break;
        case 9: _t->on_qlwPaths_itemSelectionChanged(); break;
        case 10: _t->on_qpbPathsAdd_clicked(); break;
        case 11: _t->on_qpbPathsRemove_clicked(); break;
        case 12: _t->on_qlwBlacklist_itemSelectionChanged(); break;
        case 13: _t->on_qpbBlacklistAdd_clicked(); break;
        case 14: _t->on_qpbBlacklistRemove_clicked(); break;
        case 15: _t->on_qcbEnable_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->on_qcbShowFps_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 17: _t->on_qcbShowTime_stateChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 18: _t->on_qpbFpsFont_clicked(); break;
        case 19: _t->on_qpbFpsColor_clicked(); break;
        case 20: _t->on_qpbLoadPreset_clicked(); break;
        case 21: _t->on_qpbSavePreset_clicked(); break;
        case 22: _t->resizeScene((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->resizeScene(); break;
        case 24: _t->accept(); break;
        case 25: _t->save(); break;
        case 26: _t->load((*reinterpret_cast< const Settings(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject OverlayConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<ConfigWidget::staticMetaObject>(),
    qt_meta_stringdata_OverlayConfig.data,
    qt_meta_data_OverlayConfig,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *OverlayConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OverlayConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_OverlayConfig.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::OverlayConfig"))
        return static_cast< Ui::OverlayConfig*>(this);
    return ConfigWidget::qt_metacast(_clname);
}

int OverlayConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ConfigWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 27;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
