/****************************************************************************
** Meta object code from reading C++ file 'ACLEditor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../mumble-1.5.901/src/mumble/ACLEditor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ACLEditor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ACLEditor_t {
    QByteArrayData data[41];
    char stringdata0[863];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ACLEditor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ACLEditor_t qt_meta_stringdata_ACLEditor = {
    {
QT_MOC_LITERAL(0, 0, 9), // "ACLEditor"
QT_MOC_LITERAL(1, 10, 6), // "accept"
QT_MOC_LITERAL(2, 17, 0), // ""
QT_MOC_LITERAL(3, 18, 9), // "refillACL"
QT_MOC_LITERAL(4, 28, 16), // "refillGroupNames"
QT_MOC_LITERAL(5, 45, 14), // "refillGroupAdd"
QT_MOC_LITERAL(6, 60, 17), // "refillGroupRemove"
QT_MOC_LITERAL(7, 78, 18), // "refillGroupInherit"
QT_MOC_LITERAL(8, 97, 16), // "refillComboBoxes"
QT_MOC_LITERAL(9, 114, 16), // "groupEnableCheck"
QT_MOC_LITERAL(10, 131, 14), // "ACLEnableCheck"
QT_MOC_LITERAL(11, 146, 24), // "on_qtwTab_currentChanged"
QT_MOC_LITERAL(12, 171, 5), // "index"
QT_MOC_LITERAL(13, 177, 28), // "on_qlwACLs_currentRowChanged"
QT_MOC_LITERAL(14, 206, 20), // "on_qpbACLAdd_clicked"
QT_MOC_LITERAL(15, 227, 23), // "on_qpbACLRemove_clicked"
QT_MOC_LITERAL(16, 251, 19), // "on_qpbACLUp_clicked"
QT_MOC_LITERAL(17, 271, 21), // "on_qpbACLDown_clicked"
QT_MOC_LITERAL(18, 293, 24), // "on_qcbACLInherit_clicked"
QT_MOC_LITERAL(19, 318, 7), // "checked"
QT_MOC_LITERAL(20, 326, 26), // "on_qcbACLApplyHere_clicked"
QT_MOC_LITERAL(21, 353, 26), // "on_qcbACLApplySubs_clicked"
QT_MOC_LITERAL(22, 380, 24), // "on_qcbACLGroup_activated"
QT_MOC_LITERAL(23, 405, 4), // "text"
QT_MOC_LITERAL(24, 410, 23), // "on_qcbACLUser_activated"
QT_MOC_LITERAL(25, 434, 22), // "ACLPermissions_clicked"
QT_MOC_LITERAL(26, 457, 21), // "qcbACLGroup_focusLost"
QT_MOC_LITERAL(27, 479, 20), // "qcbACLUser_focusLost"
QT_MOC_LITERAL(28, 500, 24), // "qcbACLGroup_spacePressed"
QT_MOC_LITERAL(29, 525, 23), // "qcbACLUser_spacePressed"
QT_MOC_LITERAL(30, 549, 25), // "on_qcbGroupList_activated"
QT_MOC_LITERAL(31, 575, 31), // "on_qcbGroupList_editTextChanged"
QT_MOC_LITERAL(32, 607, 22), // "on_qpbGroupAdd_clicked"
QT_MOC_LITERAL(33, 630, 25), // "on_qpbGroupRemove_clicked"
QT_MOC_LITERAL(34, 656, 26), // "on_qcbGroupInherit_clicked"
QT_MOC_LITERAL(35, 683, 30), // "on_qcbGroupInheritable_clicked"
QT_MOC_LITERAL(36, 714, 25), // "on_qpbGroupAddAdd_clicked"
QT_MOC_LITERAL(37, 740, 28), // "on_qpbGroupAddRemove_clicked"
QT_MOC_LITERAL(38, 769, 28), // "on_qpbGroupRemoveAdd_clicked"
QT_MOC_LITERAL(39, 798, 31), // "on_qpbGroupRemoveRemove_clicked"
QT_MOC_LITERAL(40, 830, 32) // "on_qpbGroupInheritRemove_clicked"

    },
    "ACLEditor\0accept\0\0refillACL\0"
    "refillGroupNames\0refillGroupAdd\0"
    "refillGroupRemove\0refillGroupInherit\0"
    "refillComboBoxes\0groupEnableCheck\0"
    "ACLEnableCheck\0on_qtwTab_currentChanged\0"
    "index\0on_qlwACLs_currentRowChanged\0"
    "on_qpbACLAdd_clicked\0on_qpbACLRemove_clicked\0"
    "on_qpbACLUp_clicked\0on_qpbACLDown_clicked\0"
    "on_qcbACLInherit_clicked\0checked\0"
    "on_qcbACLApplyHere_clicked\0"
    "on_qcbACLApplySubs_clicked\0"
    "on_qcbACLGroup_activated\0text\0"
    "on_qcbACLUser_activated\0ACLPermissions_clicked\0"
    "qcbACLGroup_focusLost\0qcbACLUser_focusLost\0"
    "qcbACLGroup_spacePressed\0"
    "qcbACLUser_spacePressed\0"
    "on_qcbGroupList_activated\0"
    "on_qcbGroupList_editTextChanged\0"
    "on_qpbGroupAdd_clicked\0on_qpbGroupRemove_clicked\0"
    "on_qcbGroupInherit_clicked\0"
    "on_qcbGroupInheritable_clicked\0"
    "on_qpbGroupAddAdd_clicked\0"
    "on_qpbGroupAddRemove_clicked\0"
    "on_qpbGroupRemoveAdd_clicked\0"
    "on_qpbGroupRemoveRemove_clicked\0"
    "on_qpbGroupInheritRemove_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ACLEditor[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      36,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,  194,    2, 0x0a /* Public */,
       3,    0,  195,    2, 0x0a /* Public */,
       4,    0,  196,    2, 0x0a /* Public */,
       5,    0,  197,    2, 0x0a /* Public */,
       6,    0,  198,    2, 0x0a /* Public */,
       7,    0,  199,    2, 0x0a /* Public */,
       8,    0,  200,    2, 0x0a /* Public */,
       9,    0,  201,    2, 0x0a /* Public */,
      10,    0,  202,    2, 0x0a /* Public */,
      11,    1,  203,    2, 0x0a /* Public */,
      13,    0,  206,    2, 0x0a /* Public */,
      14,    0,  207,    2, 0x0a /* Public */,
      15,    0,  208,    2, 0x0a /* Public */,
      16,    0,  209,    2, 0x0a /* Public */,
      17,    0,  210,    2, 0x0a /* Public */,
      18,    1,  211,    2, 0x0a /* Public */,
      20,    1,  214,    2, 0x0a /* Public */,
      21,    1,  217,    2, 0x0a /* Public */,
      22,    1,  220,    2, 0x0a /* Public */,
      24,    1,  223,    2, 0x0a /* Public */,
      25,    0,  226,    2, 0x0a /* Public */,
      26,    0,  227,    2, 0x0a /* Public */,
      27,    0,  228,    2, 0x0a /* Public */,
      28,    0,  229,    2, 0x0a /* Public */,
      29,    0,  230,    2, 0x0a /* Public */,
      30,    1,  231,    2, 0x0a /* Public */,
      31,    1,  234,    2, 0x0a /* Public */,
      32,    0,  237,    2, 0x0a /* Public */,
      33,    0,  238,    2, 0x0a /* Public */,
      34,    1,  239,    2, 0x0a /* Public */,
      35,    1,  242,    2, 0x0a /* Public */,
      36,    0,  245,    2, 0x0a /* Public */,
      37,    0,  246,    2, 0x0a /* Public */,
      38,    0,  247,    2, 0x0a /* Public */,
      39,    0,  248,    2, 0x0a /* Public */,
      40,    0,  249,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   12,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void, QMetaType::Bool,   19,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void ACLEditor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ACLEditor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->accept(); break;
        case 1: _t->refillACL(); break;
        case 2: _t->refillGroupNames(); break;
        case 3: _t->refillGroupAdd(); break;
        case 4: _t->refillGroupRemove(); break;
        case 5: _t->refillGroupInherit(); break;
        case 6: _t->refillComboBoxes(); break;
        case 7: _t->groupEnableCheck(); break;
        case 8: _t->ACLEnableCheck(); break;
        case 9: _t->on_qtwTab_currentChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->on_qlwACLs_currentRowChanged(); break;
        case 11: _t->on_qpbACLAdd_clicked(); break;
        case 12: _t->on_qpbACLRemove_clicked(); break;
        case 13: _t->on_qpbACLUp_clicked(); break;
        case 14: _t->on_qpbACLDown_clicked(); break;
        case 15: _t->on_qcbACLInherit_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->on_qcbACLApplyHere_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 17: _t->on_qcbACLApplySubs_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->on_qcbACLGroup_activated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 19: _t->on_qcbACLUser_activated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->ACLPermissions_clicked(); break;
        case 21: _t->qcbACLGroup_focusLost(); break;
        case 22: _t->qcbACLUser_focusLost(); break;
        case 23: _t->qcbACLGroup_spacePressed(); break;
        case 24: _t->qcbACLUser_spacePressed(); break;
        case 25: _t->on_qcbGroupList_activated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 26: _t->on_qcbGroupList_editTextChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 27: _t->on_qpbGroupAdd_clicked(); break;
        case 28: _t->on_qpbGroupRemove_clicked(); break;
        case 29: _t->on_qcbGroupInherit_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->on_qcbGroupInheritable_clicked((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->on_qpbGroupAddAdd_clicked(); break;
        case 32: _t->on_qpbGroupAddRemove_clicked(); break;
        case 33: _t->on_qpbGroupRemoveAdd_clicked(); break;
        case 34: _t->on_qpbGroupRemoveRemove_clicked(); break;
        case 35: _t->on_qpbGroupInheritRemove_clicked(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ACLEditor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_ACLEditor.data,
    qt_meta_data_ACLEditor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ACLEditor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ACLEditor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ACLEditor.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ACLEditor"))
        return static_cast< Ui::ACLEditor*>(this);
    return QDialog::qt_metacast(_clname);
}

int ACLEditor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 36;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
