// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: MumbleUDP.proto
// Protobuf C++ Version: 7.35.1

#ifndef MumbleUDP_2eproto_2epb_2eh
#define MumbleUDP_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_MumbleUDP_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_MumbleUDP_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_MumbleUDP_2eproto;
}  // extern "C"
namespace MumbleUDP {
class Audio;
struct AudioGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern AudioGlobalsTypeInternal Audio_globals_;
extern const ::google::protobuf::internal::ClassDataFull Audio_class_data_;
#else
extern const AudioGlobalsTypeInternal Audio_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class Ping;
struct PingGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern PingGlobalsTypeInternal Ping_globals_;
extern const ::google::protobuf::internal::ClassDataFull Ping_class_data_;
#else
extern const PingGlobalsTypeInternal Ping_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
}  // namespace MumbleUDP
namespace google {
namespace protobuf {
}  // namespace protobuf
}  // namespace google

namespace MumbleUDP {

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Ping final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:MumbleUDP.Ping) */ {
 public:
  inline Ping() : Ping(nullptr) {}
  ~Ping() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Ping* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Ping));
  }
#endif

  template <typename = void>
  explicit constexpr Ping(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Ping(const Ping& from) : Ping(nullptr, from) {}
  inline Ping(Ping&& from) noexcept : Ping(nullptr, ::std::move(from)) {}
  inline Ping& operator=(const Ping& from) {
    CopyFrom(from);
    return *this;
  }
  inline Ping& operator=(Ping&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Ping& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Ping>(&Ping_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(Ping& a, Ping& b) { a.Swap(&b); }
  inline void Swap(Ping* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Ping* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Ping* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Ping>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Ping& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Ping& from) { Ping::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Ping* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "MumbleUDP.Ping"; }

  explicit Ping(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Ping(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Ping& from);
  Ping(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Ping&& from) noexcept
      : Ping(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kTimestampFieldNumber = 1,
    kServerVersionV2FieldNumber = 3,
    kRequestExtendedInformationFieldNumber = 2,
    kUserCountFieldNumber = 4,
    kMaxUserCountFieldNumber = 5,
    kMaxBandwidthPerUserFieldNumber = 6,
  };
  // uint64 timestamp = 1;
  void clear_timestamp() ;
  [[nodiscard]] ::uint64_t timestamp() const;
  void set_timestamp(::uint64_t value);

  private:
  ::uint64_t _internal_timestamp() const;
  void _internal_set_timestamp(::uint64_t value);

  public:
  // uint64 server_version_v2 = 3;
  void clear_server_version_v2() ;
  [[nodiscard]] ::uint64_t server_version_v2() const;
  void set_server_version_v2(::uint64_t value);

  private:
  ::uint64_t _internal_server_version_v2() const;
  void _internal_set_server_version_v2(::uint64_t value);

  public:
  // bool request_extended_information = 2;
  void clear_request_extended_information() ;
  [[nodiscard]] bool request_extended_information() const;
  void set_request_extended_information(bool value);

  private:
  bool _internal_request_extended_information() const;
  void _internal_set_request_extended_information(bool value);

  public:
  // uint32 user_count = 4;
  void clear_user_count() ;
  [[nodiscard]] ::uint32_t user_count() const;
  void set_user_count(::uint32_t value);

  private:
  ::uint32_t _internal_user_count() const;
  void _internal_set_user_count(::uint32_t value);

  public:
  // uint32 max_user_count = 5;
  void clear_max_user_count() ;
  [[nodiscard]] ::uint32_t max_user_count() const;
  void set_max_user_count(::uint32_t value);

  private:
  ::uint32_t _internal_max_user_count() const;
  void _internal_set_max_user_count(::uint32_t value);

  public:
  // uint32 max_bandwidth_per_user = 6;
  void clear_max_bandwidth_per_user() ;
  [[nodiscard]] ::uint32_t max_bandwidth_per_user() const;
  void set_max_bandwidth_per_user(::uint32_t value);

  private:
  ::uint32_t _internal_max_bandwidth_per_user() const;
  void _internal_set_max_bandwidth_per_user(::uint32_t value);

  public:
  // @@protoc_insertion_point(class_scope:MumbleUDP.Ping)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 6,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Ping& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::uint64_t timestamp_;
    ::uint64_t server_version_v2_;
    bool request_extended_information_;
    ::uint32_t user_count_;
    ::uint32_t max_user_count_;
    ::uint32_t max_bandwidth_per_user_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_MumbleUDP_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Audio final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:MumbleUDP.Audio) */ {
 public:
  inline Audio() : Audio(nullptr) {}
  ~Audio() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Audio* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Audio));
  }
#endif

  template <typename = void>
  explicit constexpr Audio(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Audio(const Audio& from) : Audio(nullptr, from) {}
  inline Audio(Audio&& from) noexcept : Audio(nullptr, ::std::move(from)) {}
  inline Audio& operator=(const Audio& from) {
    CopyFrom(from);
    return *this;
  }
  inline Audio& operator=(Audio&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Audio& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Audio>(&Audio_globals_);
  }
  enum HeaderCase {
    kTarget = 1,
    kContext = 2,
    HEADER_NOT_SET = 0,
  };
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(Audio& a, Audio& b) { a.Swap(&b); }
  inline void Swap(Audio* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Audio* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Audio* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Audio>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Audio& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Audio& from) { Audio::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Audio* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "MumbleUDP.Audio"; }

  explicit Audio(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Audio(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Audio& from);
  Audio(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Audio&& from) noexcept
      : Audio(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kPositionalDataFieldNumber = 6,
    kOpusDataFieldNumber = 5,
    kFrameNumberFieldNumber = 4,
    kSenderSessionFieldNumber = 3,
    kVolumeAdjustmentFieldNumber = 7,
    kIsTerminatorFieldNumber = 16,
    kTargetFieldNumber = 1,
    kContextFieldNumber = 2,
  };
  // repeated float positional_data = 6;
  [[nodiscard]] int positional_data_size()
      const;
  private:
  int _internal_positional_data_size() const;

  public:
  void clear_positional_data() ;
  [[nodiscard]] float positional_data(int index) const;
  void set_positional_data(int index, float value);
  void add_positional_data(float value);
  [[nodiscard]] const ::google::protobuf::RepeatedField<float>& positional_data()
      const;
  ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL mutable_positional_data();

  private:
  const ::google::protobuf::RepeatedField<float>& _internal_positional_data() const;
  ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL _internal_mutable_positional_data();

  public:
  // bytes opus_data = 5;
  void clear_opus_data() ;
  [[nodiscard]] const ::std::string& opus_data() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_opus_data(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_opus_data();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_opus_data();
  void set_allocated_opus_data(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_opus_data() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_opus_data(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_opus_data();

  public:
  // uint64 frame_number = 4;
  void clear_frame_number() ;
  [[nodiscard]] ::uint64_t frame_number() const;
  void set_frame_number(::uint64_t value);

  private:
  ::uint64_t _internal_frame_number() const;
  void _internal_set_frame_number(::uint64_t value);

  public:
  // uint32 sender_session = 3;
  void clear_sender_session() ;
  [[nodiscard]] ::uint32_t sender_session() const;
  void set_sender_session(::uint32_t value);

  private:
  ::uint32_t _internal_sender_session() const;
  void _internal_set_sender_session(::uint32_t value);

  public:
  // float volume_adjustment = 7;
  void clear_volume_adjustment() ;
  [[nodiscard]] float volume_adjustment() const;
  void set_volume_adjustment(float value);

  private:
  float _internal_volume_adjustment() const;
  void _internal_set_volume_adjustment(float value);

  public:
  // bool is_terminator = 16;
  void clear_is_terminator() ;
  [[nodiscard]] bool is_terminator() const;
  void set_is_terminator(bool value);

  private:
  bool _internal_is_terminator() const;
  void _internal_set_is_terminator(bool value);

  public:
  // uint32 target = 1;
  [[nodiscard]] bool has_target()
      const;
  void clear_target() ;
  [[nodiscard]] ::uint32_t target() const;
  void set_target(::uint32_t value);

  private:
  ::uint32_t _internal_target() const;
  void _internal_set_target(::uint32_t value);

  public:
  // uint32 context = 2;
  [[nodiscard]] bool has_context()
      const;
  void clear_context() ;
  [[nodiscard]] ::uint32_t context() const;
  void set_context(::uint32_t value);

  private:
  ::uint32_t _internal_context() const;
  void _internal_set_context(::uint32_t value);

  public:
  void clear_Header();
  HeaderCase Header_case() const;
  // @@protoc_insertion_point(class_scope:MumbleUDP.Audio)
 private:
  class _Internal;
  void set_has_target();
  void set_has_context();
  [[nodiscard]] inline bool has_Header() const;
  inline void clear_has_Header();
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<3, 8,
                          0, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Audio& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedField<float> positional_data_;
    ::google::protobuf::internal::ArenaStringPtr opus_data_;
    ::uint64_t frame_number_;
    ::uint32_t sender_session_;
    float volume_adjustment_;
    bool is_terminator_;
    union HeaderUnion {
      constexpr HeaderUnion() : _constinit_{} {}
      ::google::protobuf::internal::ConstantInitialized _constinit_;
      ::uint32_t target_;
      ::uint32_t context_;
    } Header_;
    ::uint32_t _oneof_case_[1];
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_MumbleUDP_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// Audio

// uint32 target = 1;
inline bool Audio::has_target() const {
  return Header_case() == kTarget;
}
inline void Audio::set_has_target() {
  _impl_._oneof_case_[0] = kTarget;
}
inline void Audio::clear_target() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Header_case() == kTarget) {
    _impl_.Header_.target_ = 0u;
    clear_has_Header();
  }
}
inline ::uint32_t Audio::target() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.target)
  return _internal_target();
}
inline void Audio::set_target(::uint32_t value) {
  if (Header_case() != kTarget) {
    clear_Header();
    set_has_target();
  }
  _impl_.Header_.target_ = value;
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.target)
}
inline ::uint32_t Audio::_internal_target() const {
  if (Header_case() == kTarget) {
    return _impl_.Header_.target_;
  }
  return 0u;
}

// uint32 context = 2;
inline bool Audio::has_context() const {
  return Header_case() == kContext;
}
inline void Audio::set_has_context() {
  _impl_._oneof_case_[0] = kContext;
}
inline void Audio::clear_context() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (Header_case() == kContext) {
    _impl_.Header_.context_ = 0u;
    clear_has_Header();
  }
}
inline ::uint32_t Audio::context() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.context)
  return _internal_context();
}
inline void Audio::set_context(::uint32_t value) {
  if (Header_case() != kContext) {
    clear_Header();
    set_has_context();
  }
  _impl_.Header_.context_ = value;
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.context)
}
inline ::uint32_t Audio::_internal_context() const {
  if (Header_case() == kContext) {
    return _impl_.Header_.context_;
  }
  return 0u;
}

// uint32 sender_session = 3;
inline void Audio::clear_sender_session() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.sender_session_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline ::uint32_t Audio::sender_session() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.sender_session)
  return _internal_sender_session();
}
inline void Audio::set_sender_session(::uint32_t value) {
  _internal_set_sender_session(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.sender_session)
}
inline ::uint32_t Audio::_internal_sender_session() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.sender_session_;
}
inline void Audio::_internal_set_sender_session(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.sender_session_ = value;
}

// uint64 frame_number = 4;
inline void Audio::clear_frame_number() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.frame_number_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline ::uint64_t Audio::frame_number() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.frame_number)
  return _internal_frame_number();
}
inline void Audio::set_frame_number(::uint64_t value) {
  _internal_set_frame_number(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.frame_number)
}
inline ::uint64_t Audio::_internal_frame_number() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.frame_number_;
}
inline void Audio::_internal_set_frame_number(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.frame_number_ = value;
}

// bytes opus_data = 5;
inline void Audio::clear_opus_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.opus_data_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& Audio::opus_data() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.opus_data)
  return _internal_opus_data();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Audio::set_opus_data(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.opus_data_.SetBytes(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.opus_data)
}
inline ::std::string* PROTOBUF_NONNULL Audio::mutable_opus_data()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_opus_data();
  // @@protoc_insertion_point(field_mutable:MumbleUDP.Audio.opus_data)
  return _s;
}
inline const ::std::string& Audio::_internal_opus_data() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.opus_data_.Get();
}
inline void Audio::_internal_set_opus_data(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.opus_data_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Audio::_internal_mutable_opus_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.opus_data_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Audio::release_opus_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:MumbleUDP.Audio.opus_data)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.opus_data_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.opus_data_.Set("", GetArena());
  }
  return released;
}
inline void Audio::set_allocated_opus_data(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.opus_data_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.opus_data_.IsDefault()) {
    _impl_.opus_data_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:MumbleUDP.Audio.opus_data)
}

// repeated float positional_data = 6;
inline int Audio::_internal_positional_data_size() const {
  return _internal_positional_data().size();
}
inline int Audio::positional_data_size() const {
  return _internal_positional_data_size();
}
inline void Audio::clear_positional_data() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.positional_data_.Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline float Audio::positional_data(int index) const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.positional_data)
  return _internal_positional_data().Get(index);
}
inline void Audio::set_positional_data(int index, float value) {
  _internal_mutable_positional_data()->Set(index, value);
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.positional_data)
}
inline void Audio::add_positional_data(float value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_positional_data()
      ->InternalAddWithArena<const ::google::protobuf::MessageLite*>(
          internal_visibility(), this, value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:MumbleUDP.Audio.positional_data)
}
inline const ::google::protobuf::RepeatedField<float>& Audio::positional_data() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:MumbleUDP.Audio.positional_data)
  return _internal_positional_data();
}
inline ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL Audio::mutable_positional_data()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:MumbleUDP.Audio.positional_data)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_positional_data();
}
inline const ::google::protobuf::RepeatedField<float>&
Audio::_internal_positional_data() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.positional_data_;
}
inline ::google::protobuf::RepeatedField<float>* PROTOBUF_NONNULL
Audio::_internal_mutable_positional_data() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.positional_data_;
}

// float volume_adjustment = 7;
inline void Audio::clear_volume_adjustment() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.volume_adjustment_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline float Audio::volume_adjustment() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.volume_adjustment)
  return _internal_volume_adjustment();
}
inline void Audio::set_volume_adjustment(float value) {
  _internal_set_volume_adjustment(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.volume_adjustment)
}
inline float Audio::_internal_volume_adjustment() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.volume_adjustment_;
}
inline void Audio::_internal_set_volume_adjustment(float value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.volume_adjustment_ = value;
}

// bool is_terminator = 16;
inline void Audio::clear_is_terminator() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.is_terminator_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline bool Audio::is_terminator() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Audio.is_terminator)
  return _internal_is_terminator();
}
inline void Audio::set_is_terminator(bool value) {
  _internal_set_is_terminator(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Audio.is_terminator)
}
inline bool Audio::_internal_is_terminator() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.is_terminator_;
}
inline void Audio::_internal_set_is_terminator(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.is_terminator_ = value;
}

inline bool Audio::has_Header() const {
  return Header_case() != HEADER_NOT_SET;
}
inline void Audio::clear_has_Header() {
  _impl_._oneof_case_[0] = HEADER_NOT_SET;
}
inline Audio::HeaderCase Audio::Header_case() const {
  return Audio::HeaderCase(_impl_._oneof_case_[0]);
}
// -------------------------------------------------------------------

// Ping

// uint64 timestamp = 1;
inline void Ping::clear_timestamp() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.timestamp_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline ::uint64_t Ping::timestamp() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Ping.timestamp)
  return _internal_timestamp();
}
inline void Ping::set_timestamp(::uint64_t value) {
  _internal_set_timestamp(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Ping.timestamp)
}
inline ::uint64_t Ping::_internal_timestamp() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.timestamp_;
}
inline void Ping::_internal_set_timestamp(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.timestamp_ = value;
}

// bool request_extended_information = 2;
inline void Ping::clear_request_extended_information() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.request_extended_information_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline bool Ping::request_extended_information() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Ping.request_extended_information)
  return _internal_request_extended_information();
}
inline void Ping::set_request_extended_information(bool value) {
  _internal_set_request_extended_information(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Ping.request_extended_information)
}
inline bool Ping::_internal_request_extended_information() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.request_extended_information_;
}
inline void Ping::_internal_set_request_extended_information(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.request_extended_information_ = value;
}

// uint64 server_version_v2 = 3;
inline void Ping::clear_server_version_v2() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.server_version_v2_ = ::uint64_t{0u};
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline ::uint64_t Ping::server_version_v2() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Ping.server_version_v2)
  return _internal_server_version_v2();
}
inline void Ping::set_server_version_v2(::uint64_t value) {
  _internal_set_server_version_v2(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Ping.server_version_v2)
}
inline ::uint64_t Ping::_internal_server_version_v2() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.server_version_v2_;
}
inline void Ping::_internal_set_server_version_v2(::uint64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.server_version_v2_ = value;
}

// uint32 user_count = 4;
inline void Ping::clear_user_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.user_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
}
inline ::uint32_t Ping::user_count() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Ping.user_count)
  return _internal_user_count();
}
inline void Ping::set_user_count(::uint32_t value) {
  _internal_set_user_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Ping.user_count)
}
inline ::uint32_t Ping::_internal_user_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.user_count_;
}
inline void Ping::_internal_set_user_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.user_count_ = value;
}

// uint32 max_user_count = 5;
inline void Ping::clear_max_user_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.max_user_count_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
}
inline ::uint32_t Ping::max_user_count() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Ping.max_user_count)
  return _internal_max_user_count();
}
inline void Ping::set_max_user_count(::uint32_t value) {
  _internal_set_max_user_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Ping.max_user_count)
}
inline ::uint32_t Ping::_internal_max_user_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.max_user_count_;
}
inline void Ping::_internal_set_max_user_count(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.max_user_count_ = value;
}

// uint32 max_bandwidth_per_user = 6;
inline void Ping::clear_max_bandwidth_per_user() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.max_bandwidth_per_user_ = 0u;
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline ::uint32_t Ping::max_bandwidth_per_user() const {
  // @@protoc_insertion_point(field_get:MumbleUDP.Ping.max_bandwidth_per_user)
  return _internal_max_bandwidth_per_user();
}
inline void Ping::set_max_bandwidth_per_user(::uint32_t value) {
  _internal_set_max_bandwidth_per_user(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:MumbleUDP.Ping.max_bandwidth_per_user)
}
inline ::uint32_t Ping::_internal_max_bandwidth_per_user() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.max_bandwidth_per_user_;
}
inline void Ping::_internal_set_max_bandwidth_per_user(::uint32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.max_bandwidth_per_user_ = value;
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace MumbleUDP


// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // MumbleUDP_2eproto_2epb_2eh
