// Copyright 2021-2023 The Mumble Developers. All rights reserved.
// Use of this source code is governed by a BSD-style license
// that can be found in the LICENSE file at the root of the
// Mumble source tree or at <https://www.mumble.info/LICENSE>.

#include "CompletablePage.h"

CompletablePage::CompletablePage(QWizard *parent) : QWizardPage(parent) {
	m_complete = true;
}

void CompletablePage::setComplete(const bool complete) {
	m_complete = complete;
	emit completeChanged();
}
